@@ -4,17 +4,19 @@
 @description: 
 """
 from enum import Enum
-from typing import List, Union, Optional
+from typing import List
+
 import numpy as np
 import torch
+from loguru import logger
 from numpy import ndarray
 from torch import Tensor
-from loguru import logger
-from text2vec.utils.tokenizer import JiebaTokenizer
-from text2vec.word2vec import Word2Vec
+
 from text2vec.sentence_model import SentenceModel, device, EncoderType
 from text2vec.utils.distance import cosine_distance
-
+from text2vec.utils.tokenizer import JiebaTokenizer
+from text2vec.word2vec import Word2Vec
+from text2vec.utils.get_file import deprecated
 
 class SimilarityType(Enum):
     WMD = 0
@@ -77,6 +79,7 @@ class Similarity:
         return f"<Similarity> model : {self.model}, similarity_type: {self.similarity_type}, " \
                f"embedding_type: {self.embedding_type}"
 
+    @deprecated("Use similarities instead, `pip install similarities`")
     def get_score(self, sentence1: str, sentence2: str) -> float:
         """
         Get score between text1 and text2
@@ -100,6 +103,7 @@ class Similarity:
             res = 1. / (1. + self.model.w2v.wmdistance(token1, token2))
         return res
 
+    @deprecated("Use similarities instead, `pip install similarities`")
     def get_scores(
             self, sentences1: List[str], sentences2: List[str], only_aligned: bool = False
     ) -> ndarray:
@@ -107,7 +111,8 @@ class Similarity:
         Get similarity scores between sentences1 and sentences2
         :param sentences1: list, sentence1 list
         :param sentences2: list, sentence2 list
-        :param only_aligned: bool, default False return all scores, if True only return scores[i][i]
+        :param only_aligned: bool, default False return all scores, if True only return scores[i][i],
+            effective when EmbeddingType.WORD2VEC
         :return: return: Matrix with res[i][j]  = cos_sim(a[i], b[j])
         """
         if not sentences1 or not sentences2:
